pub enum Setup {
Pending {
full_verify_concurrency_limit: usize,
setup: Receiver<InboundSetupData>,
},
Initialized {
cached_peer_addr_response: CachedPeerAddrResponse,
block_downloads: Pin<Box<Downloads<Timeout<Buffer<BoxService<Request, Response, BoxError>, Request>>, Timeout<Buffer<BoxService<Request, Hash, RouterError>, Request>>, Buffer<BoxService<Request, Response, BoxError>, Request>>>>,
mempool: Buffer<BoxService<Request, Response, BoxError>, Request>,
state: Buffer<BoxService<Request, Response, BoxError>, Request>,
misbehavior_sender: Sender<(PeerSocketAddr, u32)>,
},
FailedInit,
FailedRecv {
error: SharedRecvError,
},
}Expand description
Tracks the internal state of the Inbound service during setup.
Variants
Pending
Waiting for service setup to complete.
All requests are ignored.
Fields
setup: Receiver<InboundSetupData>A oneshot channel used to receive required services, after they are set up.
Initialized
Setup is complete.
All requests are answered.
Fields
cached_peer_addr_response: CachedPeerAddrResponseAn owned partial list of peer addresses used as a GetAddr response, and
a shared list of peer addresses used to periodically refresh the partial list.
Refreshed from the address book in poll_ready method
after CACHED_ADDRS_REFRESH_INTERVAL.
block_downloads: Pin<Box<Downloads<Timeout<Buffer<BoxService<Request, Response, BoxError>, Request>>, Timeout<Buffer<BoxService<Request, Hash, RouterError>, Request>>, Buffer<BoxService<Request, Response, BoxError>, Request>>>>A futures::Stream that downloads and verifies gossiped blocks.
mempool: Buffer<BoxService<Request, Response, BoxError>, Request>A service that manages transactions in the memory pool.
state: Buffer<BoxService<Request, Response, BoxError>, Request>A service that manages cached blockchain state.
misbehavior_sender: Sender<(PeerSocketAddr, u32)>A channel to send misbehavior reports to the AddressBook.
FailedInit
Temporary state used in the inbound service’s internal initialization code.
If this state occurs outside the service initialization code, the service panics.
FailedRecv
Setup failed, because the setup channel permanently failed. The service keeps returning readiness errors for every request.
Fields
error: SharedRecvErrorThe original channel error.